@@ -52,6 +52,7 @@ type Config struct {
 	LogoColor                     string
 	StartCompact                  bool
 	StartAllTasksView             bool
+	CompactTables                 bool
 }
 
 type Model struct {
@@ -169,16 +170,18 @@ func (m Model) Update(msg tea.Msg) (tea.Model, tea.Cmd) {
 			}
 			m.getCurrentPageModel().SetLoading(false)
 
+			if m.currentPage.CanBeStart() && len(msg.AllPageRows) == 0 {
+				// oddly, nomad http api errors when one provides the wrong token,
+				// but returns empty results when one provides an empty token
+				m.getCurrentPageModel().SetHeader([]string{"Error"})
+				m.getCurrentPageModel().SetAllPageData([]page.Row{
+					{"", "No results. Is the cluster empty or was no nomad token provided?"},
+					{"", "Press q or ctrl+c to quit."},
+				})
+				m.getCurrentPageModel().SetViewportSelectionEnabled(false)
+			}
+
 			switch m.currentPage {
-			case nomad.JobsPage:
-				if m.currentPage == nomad.JobsPage && len(msg.AllPageRows) == 0 {
-					// oddly, nomad http api errors when one provides the wrong token, but returns empty results when one provides an empty token
-					m.getCurrentPageModel().SetAllPageData([]page.Row{
-						{"", "No job results. Is the cluster empty or no nomad token provided?"},
-						{"", "Press q or ctrl+c to quit."},
-					})
-					m.getCurrentPageModel().SetViewportSelectionEnabled(false)
-				}
 			case nomad.JobEventsPage, nomad.AllocEventsPage, nomad.AllEventsPage:
 				m.eventsStream = msg.EventsStream
 				cmds = append(cmds, nomad.ReadEventsStreamNextMessage(m.eventsStream, m.config.Event.JQQuery))
@@ -314,7 +317,7 @@ func (m *Model) initialize() error {
 	m.client = *client
 
 	m.pageModels = make(map[nomad.Page]*page.Model)
-	for k, c := range nomad.GetAllPageConfigs(m.width, m.getPageHeight(), m.config.CopySavePath) {
+	for k, c := range nomad.GetAllPageConfigs(m.width, m.getPageHeight(), m.config.CopySavePath, m.config.CompactTables) {
 		p := page.New(c)
 		m.pageModels[k] = &p
 	}
